@@ -48,25 +48,7 @@ def paginated_webhook_urls(
     )
 
 
-def graph_components_all() -> Iterable[dict]:
-    """Iterate over all available graph components"""
-    yield from paginated_graph_components_admin()
-    yield from paginated_graph_components_regular()
-
-
 @paginated
-def paginated_graph_components_user():
-    """Components from this user's organization"""
-    return get_json(Endpoints.COMPONENTS_USER)
-
-
-@paginated
-def paginated_graph_components_admin():
-    """Components from the system"""
-    return get_json(Endpoints.COMPONENTS_ADMIN)
-
-
-@paginated
-def paginated_graph_components_regular():
-    """Components not from the system (a superset of user components)"""
-    return get_json(Endpoints.COMPONENTS_REGULAR)
+def paginated_graph_components():
+    """All public components"""
+    return get_json(Endpoints.COMPONENTS_LIST)
